@@ -29,6 +29,7 @@ public slots:
 private:
     Ui::ProfileChangerWidget *ui;
     bool showNextProfile;
+    int usageCounter;
 
 private:
     QString getProfileName();
@@ -36,6 +37,7 @@ private:
     void switchProfile();
     void showIconSilent();
     void showIconGeneral();
+    void showQuestion(QString info);
     void refreshIcon();
 };
 
