@@ -30,6 +30,14 @@
         <translation>Bitte testen Sie die aktuellste Version aus dem Extras-testing Repository.</translation>
     </message>
 </context>
+<context>
+    <name>QDialogButtonBox</name>
+    <message>
+        <location filename="main.cpp" line="72"/>
+        <source>Done</source>
+        <translation>Fertig</translation>
+    </message>
+</context>
 <context>
     <name>SettingsDialog</name>
     <message>
