@@ -1,6 +1,8 @@
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
 #include <QLibraryInfo>
+#include <QDesktopServices>
+#include <QUrl>
 
 SettingsDialog::SettingsDialog(QWidget *parent) :
     QDialog(parent),
@@ -118,15 +120,15 @@ void SettingsDialog::on_buttonBox_rejected()
 
 void SettingsDialog::openBrowser(QString url)
 {
-    QDBusMessage msg = QDBusMessage::createMethodCall(
-        "com.nokia.osso_browser", // --dest
-        "/com/nokia/osso_browser/request", // destination object path
-        "com.nokia.osso_browser", // message name (w/o method)
-        "load_url" // method
-    );
-    msg << url;
-    msg = QDBusConnection::systemBus().call(msg);
-
+    //QDBusMessage msg = QDBusMessage::createMethodCall(
+    //    "com.nokia.osso_browser", // --dest
+    //    "/com/nokia/osso_browser/request", // destination object path
+    //    "com.nokia.osso_browser", // message name (w/o method)
+    //    "load_url" // method
+    //);
+    //msg << url;
+    //msg = QDBusConnection::systemBus().call(msg);
+    QDesktopServices::openUrl(QUrl(url, QUrl::TolerantMode));
 }
 
 void SettingsDialog::showEvent(QShowEvent* event)
